#!/usr/bin/perl

use Getopt::Std;
use LWP::UserAgent;
use HTTP::Request;
use MIME::Base64;

require "conf.inc";

$version = "1.9A";

################################################################################
# SENSOR MANAGEMENT TOOLS - AANVAL INTRUSION DETECTION CONSOLE
################################################################################

go();

sub go {

    print "Aanval Console - Sensor Management Tools - v.$version\n";

	$res = httpRequest("$protocol://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");

	if ($res->is_success) {
		processMessage($res->content);
	} else {
		print "!! Error !!\nConnection Status: " . $res->status_line . "\n\nThis must be corrected to function properly!\n";
	} 
}

sub httpRequest {

	$url = $_[0];

        $ua = LWP::UserAgent->new;
		$ua->protocols_allowed( [ 'http', 'https'] );
        $ua->agent("$version" . $ua->agent);

        $req = HTTP::Request->new(GET =>, "$url");
        $req->header('Accept' => 'text/html');

        $res = $ua->request($req);

	return $res;
}

sub sendMessage {

	return $message;
}

sub processMessage {
	$message = $_[0];

	chomp($message);

	if ($message eq "SNORTRESTART") {
		$data = `$cmdSnortStop 2>/dev/null &`;
                $data = `$cmdSnortStart 2>/dev/null &`;
		$code = 1;
	} elsif ($message eq "SNORTSTOP") {
                $data = `$cmdSnortStop 2>/dev/null &`;
		$code = 2;
	} elsif ($message eq "SNORTSTART") {
                $data = `$cmdSnortStart 2>/dev/null &`;
		$code = 3;
        } elsif ($message eq "UPTIME") {
                $data = `$cmdUptime 2>/dev/null &`;
		$data = encode_base64($data);
		$res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?uptime=$data");
                $code = 4;
        } elsif ($message eq "SNORTCONFGET") {

		my $url = "http://$consoleHost$consoleHostPath/poll/sensor_poll.php?confsend=1&id=$id";
		my $ua = LWP::UserAgent->new();
		use HTTP::Request::Common qw/POST/;

		$request = POST $url, Content_Type=>'form-data', Content => [conf=>[$confSnort]];

		my $results=$ua->request($request);
		if($results->is_success){
		   print "File Transfer Success\n";
		} else {
		   print "File Transfer Failed\n";
		   print $results->status_line();
		}

		$code = 5;
        } elsif ($message eq "SNORTCONFSEND") {
            $res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?confget=1&id=$id");
            $content = decode_base64($res->content);
            if ($res->is_success) {
                    writeSnortConf($content);
            }
            $code = 6;
        } elsif ($message eq "SNORTRULESGET") {

		@files = <$rulesSnort*.rules>;

		foreach(@files) {
	                my $url = "http://$consoleHost$consoleHostPath/poll/sensor_poll.php?rulessend=1&id=$id";
	                my $ua = LWP::UserAgent->new();
	                use HTTP::Request::Common qw/POST/;

			$request = POST $url, Content_Type=>'form-data', Content => [rules=>[$_]];

			print "$_ :: ";

	                my $results=$ua->request($request);
	                if($results->is_success){
	                   print "File Transfer Success\n";
	                   print $results->content();
	                } else {
	                   print "File Transfer Failed\n";
	                   print $results->status_line();
	                }
	                $res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");
		}

                $code = 7;
        } elsif ($message eq "SNORTRULESSEND") {

            $res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?rulesget=1&id=$id");

            if ($res->is_success) {
        		@ruleList = split(/\n/, $res->content);
    		}

    		foreach(@ruleList) {
                $res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?ruleget=1&rule=$_&id=$id");
                $content = decode_base64($res->content);
                if ($res->is_success) {
                    writeSnortRule($_, $content);
                    $res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id");
                }

    		}

            $code = 8;
        } elsif ($message eq "SENSORUPDATE") {
                $res = httpRequest("http://$consoleHost$consoleHostPath/contrib/sensors/processor.pl");

                if ($res->is_success) {
                        writeUpdate($res->content);
                }

		$code = 9;
        } elsif ($message eq "SNORTSTATUS") {
			$data = `$cmdSnortStatus 2>/dev/null &`;
    	    $data = encode_base64($data);
        	$res = httpRequest("http://$consoleHost$consoleHostPath/poll/sensor_poll.php?id=$id&snortstatus=1&data=$data");

            $code = 10;
	 	} else {
			$code = 0;
		}

	print "Waiting Message: $message\nMessage Code: $code\n\n";
}

sub writeSnortConf {

	$data = $_[0];

	open(FILE, ">$confSnort");
	print FILE "$data";
	close(FILE);
}

sub writeUpdate {

        $data = $_[0];

        open(FILE, ">$sensorDataPath/processor.pl.NEW");
        print FILE "$data";
        close(FILE);
}

sub writeSnortRule {

	$rule = $_[0];
        $data = $_[1];

        open(FILE, ">$rulesSnort$rule");
        print FILE "$data";
        close(FILE);
}

