<?php

/** Copyright 2005 Remote Assessment
 *
 * Aanval - Intrusion Detection Console
 *
 * This program is owned and licensed by Remote Assessment; it may be
 * redistributed only in its original configuration as originally
 * installed and available by Remote Assessment and / or Aanval.
 *
 * To license and / or include this product in other forms or
 * applications, express prior written authorization must be
 * obtained by contract from authorized Remote Assessment or Aanval personel.
 *
 * Remote Assessment and Aanval may not be held liable nor responsible
 * for issues arising from the use of, damages caused by, or conclusions drawn from the
 * use of this product.
 *
 */

// Session Settings php.ini
ini_set("session.bug_compat_42", 1);
ini_set("session.bug_compat_warn", 0);

// Check if system is in upgrade or install mode (/installation/upgrade exists when new .tar.gz is extracted)
if (file_exists('installation/upgrade')) {
	
	// Send to installation / upgrade page
    header('Location: installation/setup.php');
    exit;
}

// Check if primary configuration file exists
if (file_exists("./conf/conf.php")) {
	
	// Include primary configuration file
    include "./conf/conf.php";

} else {
	
	// FAIL - Could not find /conf/conf.php
    echo "<b>Aanval - Intrusion Detection Console<p>ERROR: /conf/conf.php not found!<br>\nCheck to ensure it exists and / or permissions are set appropriately.<br>";
	exit;
}

// Register page speed processing variable
$start_time = getmicrotime();

// Load appropriate modules
recursiveModuleLoad();

// Session Initilization
$username = getVar("username");
$password = getVar("password");

// User Variables
$login = new mySession("aanval");
$login->initSession($username, $password);
$login->loadSession();

// Ops Variable Initilization
$ops = new myOps();
$ops->loadOps();

// Load Language Pack
// Check if base language pack exists and load
if (file_exists("./language/English.php")) {
	
    // Load the users specific language pack
	if (file_exists("./language/" . $login->getSessionVar("lang") . ".php")) {
		
		// Include primary configuration file
	    include "./language/" . $login->getSessionVar("lang") . ".php";
	
	}    
	
	// Include primary english language pack
    include "./language/English.php";	
  	
} else {
	
	// FAIL - Could not find /language/english.php
    echo "<b>Aanval - Intrusion Detection Console<p>ERROR: /language/English.php not found!<br>\nCheck to ensure it exists and / or permissions are set appropriately.<br>";
	exit;
}

// OP Switch
$op = getVar("op");
if (!$op) {
	if ($login->getSessionVar("login")) {
		$op = "prv_main";
	} else {
		$op = "pub_login";
	}
}

// Catch any special keywords (ie: help, ops, etc)
$search = getVar("search");
if ($search) {
    dblog($op, "Go!", 0, "$search");
    if (strtolower($search) == "help!") {
        $op = "prv_searchHelp";
        setVar("search", "");
    } else if (strtolower($search) == "system!") {
        $op = "prv_systemManager";
        setVar("search", "");
    } else if (strtolower($search) == "status!") {
        $op = "prv_statusManager";
        setVar("search", "");
    } else if (strtolower($search) == "logs!") {
        $op = "prv_logsManager";
        setVar("search", "");
    } else if (strtolower($search) == "chat!") {
        $op = "prv_monitor";
        setVar("vis", "9");
        setVar("search", "");
    } else if (strtolower($search) == "main!") {
        $op = "prv_main";
        setVar("search", "");
    } else if (strstr(strtolower($search), "ping:")) {
        $op = "prv_addScan";
        $redir = "?op=prv_scanningManager";
        $search = str_replace("ping:", "", $search);
        setVar("ip", trim($search));
        setVar("type", "1");
        setVar("search", "");
    } else if (strstr(strtolower($search), "lightscan:")) {
        $op = "prv_addScan";
        $redir = "?op=prv_scanningManager";
        $search = str_replace("lightscan:", "", $search);
        setVar("ip", trim($search));
        setVar("type", "2");
        setVar("search", "");
    } else if (strstr(strtolower($search), "heavyscan:")) {
        $op = "prv_addScan";
        $redir = "?op=prv_scanningManager";
        $search = str_replace("heavyscan:", "", $search);
        setVar("ip", trim($search));
        setVar("type", "3");
        setVar("search", "");
    } else if (strtolower($search) == "snort!") {
        $op = "prv_moduleConfig";
        setVar("module", "1");
        setVar("search", "");
    } else if (strtolower($search) == "syslog!") {
        $op = "prv_moduleConfig";
        setVar("module", "2");
        setVar("search", "");
    } else if (strtolower($search) == "version!") {
        $op = "prv_version";
        setVar("search", "");
    } else if (strtolower($search) == "ai!") {
        $op = "prv_aiManager";
        setVar("search", "");
    } else if (strtolower($search) == "license!") {
        $op = "prv_licenseManager";
        setVar("search", "");
    } else if (strtolower($search) == "action!") {
        $op = "prv_actionManager";
        setVar("search", "");
    } else if (strtolower($search) == "notes!") {
        $op = "prv_notesManager";
        setVar("search", "");
    } else if (strtolower($search) == "collection!") {
        $op = "prv_collectionManager";
        setVar("search", "");
    } else if (strtolower($search) == "archive!") {
        $op = "prv_archiveManager";
        setVar("search", "");
    } else if (strtolower($search) == "setup!") {
        $op = "prv_gettingStarted";
        setVar("search", "");
    } else if (strtolower($search) == "graphs!") {
        $op = "prv_graphs";
        setVar("search", "");
    } else if (strtolower($search) == "logout!") {
        $op = "pub_logout";
        $redir = "?";
        setVar("search", "");
    } else if (strtolower($search) == "licensemonitor!") {
        $op = "prv_licenseMonitor";
        setVar("search", "");
    } else if (strstr(strtolower($search), "resetsensor:")) {
        $op = "prv_snortSensorReset";
        $redir = "?";
        $sensor = str_replace("resetsensor:", "", $search);
        setVar("sensor", "$sensor");
        setVar("search", "");
    }
}

// Redirection Feature
if (!$redir) $redir = getVar("redir");
if (!$eredir) $eredir = getVar("eredir");
if ($redir) {
	if (getVar("rtime")) {
		$rt = strip_tags(addslashes(getVar("rtime")));
	} else {
		$rt = $ops->getOpsVar("site_redirectTime");
	}
	if (getVar("popup")) {
		$redir = "$redir&popup=1";
	}
        $location = "<meta HTTP-EQUIV='REFRESH' TARGET='_blank' CONTENT='$rt;URL=$redir'>";
        echo "$location";
}
if ($eredir) {
	$eredir = base64_decode($eredir);

        if (getVar("rtime")) {
                $rt = strip_tags(addslashes(getVar("rtime")));
        } else {
                $rt = 2;
        }
        if (getVar("popup")) {
                $eredir = "$eredir&popup=1";
        }
        $location = "<meta HTTP-EQUIV='REFRESH' TARGET='_blank' CONTENT='$rt;URL=$eredir'>";
        echo "$location";
}

# Decides which OP parameters to allow and which to deny
$chunk = substr($op, 0, 4);
if ($chunk == "pub_") {
	dblog($op, "Public Ops Navigation", 0, "");
	echo site("$op");
} else if ($chunk == "prv_") {
	if ($login && $login->getSessionVar("login")) {
		dblog($op, "Private Ops Navigation", 0, "");
		echo site("$op");
	} else {
		// unauthorized
		dblog($op, "Private Ops Navigation", 0, "UNAUTHORIZED");
		echo site("pub_unauthorized");
	}
} else {
	// unauthorized
	dblog($op, "UNKNOWN Ops Navigation", 0, "UNAUTHORIZED");
	echo site("pub_unauthorized");
}

// Read in all available modules recursively
function recursiveModuleLoad() {
	global $root_path;

	if (!$this_dir = @dir("$root_path/modules/")) {
	        echo "conf.php ERROR:<p>\$root_path not correct or $root_path/modules/ not found! Check your conf.php settings<p>Exiting.";
	        exit;
	}
	while ($dir = $this_dir->read()) {
	        if ($dir != "." && $dir != "..") {
	                if (substr($dir, -4, 4) == "_MOD") {
	                        $this_sub = dir("$root_path/modules/$dir");
	                        while ($file = $this_sub->read()) {
	                                if ($file != "." && $file != "..") {
	                                        if (substr($file, 0,4) == "inc_") {
	                                                include "$root_path/modules/$dir/$file";
	                                        }
	                                }
	                        }
	                }
	        }
	}
}

function getmicrotime() { 
	list($usec, $sec) = explode(" ", microtime()); 
	
	return ((float)$usec + (float)$sec); 
}

?>
